@@ -399,7 +399,10 @@ class TestDnsmasqRouted(base.BaseTestCase):
         network.non_local_subnets = []
         network.get.side_effect = lambda key, dflt=None: dflt
         device_mgr_cls.return_value.driver.bridged = False
-        dhcp_driver = DnsmasqRouted(cfg.CONF, network, None)
+        dhcp_driver = DnsmasqRouted(cfg.CONF,
+                                    network,
+                                    None,
+                                    plugin=FakePlugin())
         with mock.patch.object(dhcp_driver, '_get_value_from_conf_file') as gv:
             gv.return_value = 'ns-dhcp'
             cmdline = dhcp_driver._build_cmdline_callback('/run/pid_file')
@@ -419,7 +422,6 @@ class TestDnsmasqRouted(base.BaseTestCase):
             '--dhcp-range=set:tag0,10.28.0.0,static,255.255.255.0,86400s',
             '--dhcp-lease-max=16777216',
             '--conf-file=',
-            '--domain=openstacklocal',
             '--dhcp-range=set:tag1,2001:db8:1::,static,off-link,80,86400s',
             '--enable-ra',
             '--interface=tap1',
